package com.caimei365.manager.config;

import cn.hutool.core.date.DateUtil;
import com.caimei365.manager.entity.ResponseJson;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.bind.WebDataBinder;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.InitBinder;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.servlet.http.HttpServletRequest;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.beans.PropertyEditorSupport;
import java.io.PrintWriter;
import java.io.StringWriter;
import java.time.LocalDateTime;
import java.util.Date;
import java.util.Iterator;
import java.util.Set;

import static cn.hutool.core.date.DatePattern.NORM_DATETIME_PATTERN;
import static cn.hutool.core.date.DatePattern.NORM_DATE_PATTERN;
@Slf4j
@ControllerAdvice
public class GlobalControllerAdvice {

    @ResponseBody
    @ExceptionHandler(value = ConstraintViolationException.class)
    public ResponseJson ConstraintViolationExceptionHandler(ConstraintViolationException ex) {
        Set<ConstraintViolation<?>> constraintViolations = ex.getConstraintViolations();
        Iterator<ConstraintViolation<?>> iterator = constraintViolations.iterator();
        String msg ="入参错误！";
        if (iterator.hasNext()) {
            ConstraintViolation<?> cvl = iterator.next();
            // msg=cvl.getPropertyPath().toString().split("\\.")[1] + " " + cvl.getMessageTemplate();
            msg = cvl.getMessageTemplate();
        }
        return ResponseJson.error(msg);
    }

    @ResponseBody
    @ExceptionHandler(value = Exception.class)
    public ResponseJson Exception(HttpServletRequest request, Exception e) {
        StringWriter stringWriter = new StringWriter();
        e.printStackTrace(new PrintWriter(stringWriter));
        log.error("出错了：[\u001B[31m {} \u001B[0m]", stringWriter);
        return ResponseJson.error("操作失败!");
    }

    @InitBinder
    public void initBinder(WebDataBinder binder) {
        binder.registerCustomEditor(LocalDateTime.class, new PropertyEditorSupport() {
            @Override
            public void setAsText(String text) {
                if (StringUtils.isNotBlank(text)) {
                    setValue(DateUtil.parseLocalDateTime(text));
                }
            }
        });
        binder.registerCustomEditor(Date.class, new PropertyEditorSupport() {
            @Override
            public void setAsText(String text) {
                if (StringUtils.isNotBlank(text)) {
                    setValue(DateUtil.parse(text, NORM_DATETIME_PATTERN, NORM_DATE_PATTERN));
                }
            }
        });
    }
}
