package com.caimei365.manager.controller.caimei.page;

import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.caimei.page.NewPageAdvertisementImage;
import com.caimei365.manager.entity.caimei.page.NewPageTopAdvertisementImage;
import com.caimei365.manager.entity.caimei.page.NewPageZone;
import com.caimei365.manager.entity.caimei.page.NewPageZoneImage;
import com.caimei365.manager.entity.caimei.product.Product;
import com.caimei365.manager.service.caimei.page.NewPageZoneService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * 网页管理接口
 */
@RestController
@RequestMapping("/page")
public class WebPageApi {

    @Autowired
    private NewPageZoneService newPageZoneService;

    @GetMapping("/zoneList")
    public ResponseJson<PaginationVo<NewPageZone>> pageZoneList(@RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return newPageZoneService.getZoneList(pageNum, pageSize);
    }

    @PostMapping("/saveZone")
    public ResponseJson saveZone(@RequestBody NewPageZone pageZone) {
        return newPageZoneService.saveZone(pageZone);
    }

    @GetMapping("/delZone")
    public ResponseJson delZone(Integer id) {
        return newPageZoneService.delZone(id);
    }

    /**
     * @param id
     * @param status 0停用 1启用
     * @param type   0www 1小程序
     * @return
     */
    @GetMapping("/updateEnabledStatus")
    public ResponseJson updateEnabledStatus(Integer id, Integer status, Integer type) {
        return newPageZoneService.updateEnabledStatus(id, status, type);
    }

    @GetMapping("/updateSort")
    public ResponseJson updateSort(Integer id, Integer sort) {
        if (null == id) {
            return ResponseJson.error(-1, "专区id不能为空", null);
        }
        if (null == sort) {
            return ResponseJson.error(-1, "排序值不能为空", null);
        }
        return newPageZoneService.updateSort(id, sort);
    }

    /**
     * 专区商品列表
     *
     * @param id
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/zoneProductList")
    public ResponseJson<PaginationVo<Product>> pageZoneProductList(Integer id, String shopName, Integer productId,
                                                                   @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                   @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return newPageZoneService.getZoneProductList(id, shopName, productId, pageNum, pageSize);
    }

    /**
     * 添加商品查询
     *
     * @param id
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/selectProductList")
    public ResponseJson<PaginationVo<Product>> selectProductList(Integer id, Integer productId, String shopName, String productName,
                                                                 @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                 @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return newPageZoneService.selectProductList(id, productId, shopName, productName, pageNum, pageSize);
    }

    @GetMapping("/select/recommendProductList")
    public ResponseJson<PaginationVo<Product>> recommendProductList(Integer productId, String shopName, String productName,
                                                                    @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                    @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return newPageZoneService.recommendProductList(productId, shopName, productName, pageNum, pageSize);
    }

    @GetMapping("/delZoneProduct")
    public ResponseJson delZoneProduct(Integer id, String ids) {
        return newPageZoneService.delZoneProduct(id, ids);
    }

    @GetMapping("/addZoneProduct")
    public ResponseJson addZoneProduct(Integer id, String ids) {
        return newPageZoneService.addZoneProduct(id, ids);
    }

    @GetMapping("/updateProductSort")
    public ResponseJson updateProductSort(Integer id, Integer productId, Integer sort) {
        if (null == id) {
            return ResponseJson.error(-1, "专区id不能为空", null);
        }
        if (null == productId) {
            return ResponseJson.error(-1, "商品id不能为空", null);
        }
        if (null == sort) {
            return ResponseJson.error(-1, "排序值不能为空", null);
        }
        return newPageZoneService.updateProductSort(id, productId, sort);
    }

    /**
     * 专区轮播图
     *
     * @param id
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/zoneImageList")
    public ResponseJson<PaginationVo<NewPageZoneImage>> pageZoneImageList(Integer id,
                                                                          @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                          @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return newPageZoneService.getZoneImageList(id, pageNum, pageSize);
    }

    @GetMapping("/zoneImageForm")
    public ResponseJson<NewPageZoneImage> zoneImageForm(Integer imageId) {
        return newPageZoneService.getZoneImageForm(imageId);
    }

    @PostMapping("/saveZoneImage")
    public ResponseJson saveZoneImage(@RequestBody NewPageZoneImage pageZoneImage) {
        return newPageZoneService.saveZoneImage(pageZoneImage);
    }

    @GetMapping("/delZoneImage")
    public ResponseJson delZoneImage(Integer imageId) {
        return newPageZoneService.delZoneImage(imageId);
    }

    /**
     * @param imageId
     * @param status  0停用 1启用
     * @param type    0www 1小程序
     * @return
     */
    @GetMapping("/updateImageStatus")
    public ResponseJson updateImageStatus(Integer imageId, Integer status, Integer type) {
        return newPageZoneService.updateImageStatus(imageId, status, type);
    }

    @GetMapping("/updateImageSort")
    public ResponseJson updateImageSort(Integer imageId, Integer sort) {
        if (null == imageId) {
            return ResponseJson.error(-1, "id不能为空", null);
        }
        if (null == sort) {
            return ResponseJson.error(-1, "排序值不能为空", null);
        }
        return newPageZoneService.updateImageSort(imageId, sort);
    }

    /**
     * 首页商品推荐
     *
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/recommendList")
    public ResponseJson<PaginationVo<Product>> recommendList(String shopName, Integer productId,
                                                             @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                             @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return newPageZoneService.getRecommendList(shopName, productId, pageNum, pageSize);
    }

    @GetMapping("/addRecommendProduct")
    public ResponseJson addRecommendProduct(String ids) {
        return newPageZoneService.addRecommendProduct(ids);
    }

    @GetMapping("/recommendDel")
    public ResponseJson recommendDel(String ids) {
        return newPageZoneService.recommendDel(ids);
    }

    @GetMapping("/recommendSort")
    public ResponseJson recommendSort(Integer productId, Integer sort) {
        return newPageZoneService.recommendSort(productId, sort);
    }

    /**
     * pc 小广告位图
     *
     * @return
     */
    @GetMapping("/advertisement/list")
    public ResponseJson<PaginationVo<NewPageAdvertisementImage>> advertisementList(@RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                                   @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return newPageZoneService.advertisementList(pageNum, pageSize);
    }

    @GetMapping("/advertisement/form")
    public ResponseJson<NewPageAdvertisementImage> advertisementForm(Integer id) {
        return newPageZoneService.advertisementForm(id);
    }

    @PostMapping("/saveAdvertisement")
    public ResponseJson saveAdvertisement(@RequestBody NewPageAdvertisementImage image) {
        return newPageZoneService.saveAdvertisement(image);
    }

    @GetMapping("/advertisement/sort")
    public ResponseJson advertisementSort(Integer id, Integer sort) {
        return newPageZoneService.advertisementSort(id, sort);
    }

    @GetMapping("/advertisementDel")
    public ResponseJson advertisementDel(Integer id) {
        return newPageZoneService.advertisementDel(id);
    }

    /**
     * pc 专属广告图
     *
     * @return
     */
    @GetMapping("/topAdvertisement/list")
    public ResponseJson<PaginationVo<NewPageTopAdvertisementImage>> topAdvertisementList(@RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                                         @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return newPageZoneService.topAdvertisementList(pageNum, pageSize);
    }

    @GetMapping("/topAdvertisement/form")
    public ResponseJson<NewPageTopAdvertisementImage> topAdvertisementForm(Integer id) {
        return newPageZoneService.topAdvertisementForm(id);
    }

    @PostMapping("/saveTopAdvertisement")
    public ResponseJson saveTopAdvertisement(@RequestBody NewPageTopAdvertisementImage image) {
        return newPageZoneService.saveTopAdvertisement(image);
    }

    @GetMapping("/topAdvertisementDel")
    public ResponseJson topAdvertisementDel(Integer id) {
        return newPageZoneService.topAdvertisementDel(id);
    }

    @GetMapping("/updateTopStatus")
    public ResponseJson updateTopStatus(Integer id, Integer status, Integer type) {
        return newPageZoneService.updateTopStatus(id, status, type);
    }
}
