package com.caimei365.manager.controller.caimei.productArchive;

import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.caimei.productArchive.CmProductArchive;
import com.caimei365.manager.entity.caimei.productArchive.CmProductArchiveContent;
import com.caimei365.manager.service.caimei.productArchive.CmProductArchiveContentService;
import com.caimei365.manager.service.caimei.productArchive.CmProductArchiveService;
import com.github.pagehelper.PageHelper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.util.*;

/**
 * 内容库管理接口
 */
@Slf4j
@Validated
@RestController
@RequestMapping("/productArchive")
public class ProductArchiveController {

    @Resource
    private CmProductArchiveService cmProductArchiveService;
    @Resource
    private CmProductArchiveContentService cmProductArchiveContentService;

    @GetMapping("/list")
    public ResponseJson productArchiveList(String productName,
                                           String productType,
                                           Integer productClassify,
                                           @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                           @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<CmProductArchive> list = cmProductArchiveService.getCmProductArchiveList(new CmProductArchive()
                .setProductName(productName)
                .setProductType(productType)
                .setProductClassify(productClassify)
        );
        return ResponseJson.success(new PaginationVo(list));
    }

    @GetMapping("/from")
    public ResponseJson productArchiveFrom(String id) {
        return ResponseJson.success(cmProductArchiveService.getCmProductArchive(new CmProductArchive().setId(id)));
    }

    @PostMapping("/add")
    public ResponseJson productArchiveAdd(@RequestBody CmProductArchive cmProductArchive
    ) {
        cmProductArchiveService.addCmProductArchive(cmProductArchive);
        return ResponseJson.success();
    }

    @GetMapping("/content/list")
    public ResponseJson productArchiveContentList(String title,
                                                  Integer stageStatus,
                                                  Integer allStatus,
                                                  String labelIds,
                                                  @NotNull(message = "productArchiveId不能为空") Integer productArchiveId,
                                                  @NotBlank(message = "type不能为空") String type,
                                                  @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                  @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<CmProductArchiveContent> list = cmProductArchiveContentService.getCmProductArchiveContentList(new CmProductArchiveContent()
                .setType(type)
                .setProductArchiveId(productArchiveId)
                .setTitle(title)
                .setStageStatus(stageStatus)
                .setAllStatus(allStatus)
                .setLabelIds(labelIds)
        );
        return ResponseJson.success(new PaginationVo(list));
    }

    @GetMapping("/content/from")
    public ResponseJson productArchiveContentFrom(String id) {
        return ResponseJson.success(cmProductArchiveContentService.getCmProductArchiveContent(new CmProductArchiveContent().setId(id)));
    }
    @PostMapping("/content/add")
    public ResponseJson productArchiveContentAdd(@RequestBody CmProductArchiveContent cmProductArchiveContent
    ) {
        cmProductArchiveContentService.addCmProductArchiveContent(cmProductArchiveContent);
        return ResponseJson.success();
    }

    @PostMapping("content/del")
    public ResponseJson providersUpdateStatus(@NotBlank(message = "ids不能为空") String ids,
                                              @NotNull(message = "productArchiveId不能为空") Integer productArchiveId,
                                              @NotBlank(message = "type不能为空") String type) {
        for (String id : ids.split(",")) {
            cmProductArchiveContentService.delCmProductArchiveContent(new CmProductArchiveContent()
                    .setId(id)
                    .setProductArchiveId(productArchiveId)
                    .setType(type)
            );
        }
        return ResponseJson.success();
    }


}
