package com.caimei365.manager.dao;

import java.util.List;

import com.caimei365.manager.entity.caimei.CmRelated;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

/**
 * 相关资源Mapper接口
 *
 * @author Kaick
 * @date 2023-12-12
 */
@Mapper
public interface CmRelatedMapper
{
    /**
     * 通过对象查询相关资源列表
     *
     * @param cmRelated 相关资源
     * @return 相关资源集合
     */
    List<CmRelated> getCmRelatedList(CmRelated cmRelated);

    /**
     * 通过Id查询相关资源对象
     *
     * @param id 相关资源主键
     * @return 相关资源
     */
    CmRelated getCmRelatedById(String id);

    /**
     * 通过对象查询相关资源对象
     *
     * @param cmRelated 相关资源
     * @return 相关资源
     */
    CmRelated getByCmRelated(CmRelated cmRelated);

    /**
     * 通过对象查询相关资源Id
     *
     * @param cmRelated 相关资源
     * @return String
     */
    String getById(CmRelated cmRelated);


    /**
     * 通过对象查询相关资源记录总数
     *
     * @param cmRelated 相关资源
     * @return 相关资源Integer
     */
    int getCount(CmRelated cmRelated);

    /**
     * 新增相关资源
     *
     * @param cmRelated 相关资源
     * @return 结果
     */
    int addCmRelated(CmRelated cmRelated);

    /**
     * 修改相关资源
     *
     * @param cmRelated 相关资源
     * @return 结果
     */
    int updateCmRelated(CmRelated cmRelated);

    /**
     * 删除相关资源
     *
     * @param id 相关资源主键
     * @return 结果
     */
    int delCmRelatedById(String id);

    /**
     * 批量删除相关资源
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int delCmRelated(CmRelated cmRelated);

}
