package com.caimei365.manager.dao;

import com.caimei365.manager.entity.caimei.*;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2022/2/23
 */
@Mapper
public interface FinanceDao {
    /**
     * 所有用户
     */
    List<ReceiptUser> getReceiptUsers();
    /**
     * 根据ID获取收款用户
     */
    ReceiptUser getReceiptUserById(Integer id);
    /**
     * 查询是否存在当前手机号的用户
     * @param mobile 手机号
     */
    ReceiptUser getReceiptUserByMobile(String mobile);
    /**
     * 获取收款权限列表
     */
    List<ReceiptPermission> getReceiptPermissions();
    /**
     * 用户权限
     */
    List<ReceiptPermission> getReceiptPermissionsByUserId(Integer userId);
    /**
     * 新增收款用户
     */
    void insertReceiptUser(ReceiptUser receiptUser);
    /**
     * 更新收款用户
     */
    void updateReceiptUser(ReceiptUser receiptUser);
    /**
     * 删除收款用户
     */
    void deleteReceiptUser(Integer id);
    /**
     * 删除收款用户原有权限关联
     */
    void deleteReceiptPermissionRelation(Integer userId);
    /**
     * 新增收款用户权限关联
     */
    void insertReceiptPermissionRelation(Integer userId, Integer permissionId);
    /**
     * 获取收款类型
     */
    List<ReceiptType> getReceiptType();
    /**
     * 获取收款列表
     */
    List<ReceiptList> getReceiptList(ReceiptParam receiptParam);
    /**
     * 收款详情
     */
    ReceiptDetail getReceiptDetail(Integer id);
    /**
     * 收款关联
     */
    List<ReceiptRelation> getReceiptRelations(Integer receiptId);
    /**
     * 收款子订单
     */
    ReceiptOrder getReceiptOrderByShopOrderId(Integer shopOrderId);
    /**
     * 收款主订单
     */
    ReceiptOrder getOrderInfoByOrderId(Integer orderId);
    /**
     * 供应商退款,已退金额
     */
    double getRefundAmountByShopOrder(Integer shopOrderId);
    /**
     * 根据订单Id获取收款记录
     */
    List<ReceiptRecord> getReceiptRecordByOrderId(Integer orderId);
    /**
     * 退款余额金额
     */
    double getReturnBalanceAmount(Integer receiptId);
    /**
     * 统计当前订单已收款
     */
    double getAssociateAmountByOrderId(Integer orderId);
    /**
     * 统计线下余额抵扣
     */
    Double sumUserMoney(Integer orderId);
    /**
     * 统计线上余额抵扣
     */
    Double sumOnlineMoney(Integer orderId);
    /**
     * 关联会员记录
     */
    ReceiptVipInfo getReceiptVipInfo(Integer receiptId);
    /**
     * 关联优惠券购买记录
     */
    ReceiptCouponInfo getReceiptCouponInfo(Integer receiptId);
    /**
     * 收款关联的订单Id
     */
    List<Integer> getOrderIdsByReceiptId(Integer receiptId);
    /**
     * 收款关联的子订单Id
     */
    List<Integer> getShopOrderIdsByReceiptId(Integer id);
    /**
     * 统计订单款项的收款记录
     * @param orderId 订单Id
     * @param receiptId 收款Id
     */
    int getOrderReceiptCount(Integer orderId, Integer receiptId);
    /**
     * 统计子订单款项的收款记录
     * @param shopOrderId 子订单Id
     * @param receiptId 收款Id
     */
    int getShopOrderReceiptCount(Integer shopOrderId, Integer receiptId);
    /**
     * 根据订单Id获取订单
     * @param orderId 订单Id
     */
    CmOrder getOrderByOrderId(Integer orderId);
    /**
     * 更新订单状态
     */
    void updateOrderStatus(CmOrder order);
    /**
     * 判断是否是充值定金商品
     */
    int countDepositOrderProduct(Integer orderId);
    /**
     * 更新用户余额
     */
    void updateReduceUserMoney(Double money, Integer userId);
    /**
     * 保存 余额收支记录
     */
    void insertBalanceRecord(BalanceRecord balanceRecord);
    void updateBalanceRecord(BalanceRecord balanceRecord);
    /**
     * 根据子订单Id获取子订单
     * @param shopOrderId 订单Id
     */
    CmShopOrder getShopOrderById(Integer shopOrderId);
    /**
     * 子更新订单状态
     */
    void updateShopOrderStatus(CmShopOrder cmShopOrder);
    /**
     * 返佣欠款记录
     */
    RebateRecord getRebateRecordByReceiptId(Integer receiptId);
    /**
     * 获取供应商
     */
    CmShop getShopByShopId(String shopId);
    /**
     * 更新供应商可用余额
     */
    void updateShopAbleRebateAmount(CmShop shop);
    /**
     * 删除返佣欠款记录
     */
    void deleteRebateRecord(Integer receiptId);
    /**
     * 撤销收款
     */
    void cancelReceipt(ReceiptDetail receipt);

}
