package com.caimei365.manager.service.caimei.impl;


import com.caimei365.manager.dao.CmSecondInfoDao;
import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.caimei.CmSecondInfo;
import com.caimei365.manager.service.caimei.CmSecondInfoService;
import com.github.pagehelper.PageHelper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

/**
 * 二手小程序信息中心文章(CmSecondInfo)表服务实现类
 */
@Slf4j
@Service("cmSecondInfoService")
public class CmSecondInfoServiceImpl implements CmSecondInfoService {

    @Resource
    private CmSecondInfoDao cmSecondInfoDao;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @Override
    public ResponseJson<CmSecondInfo> queryById(Integer id) {
        return ResponseJson.success(cmSecondInfoDao.queryById(id));
    }

    @Override
    public ResponseJson<PaginationVo<CmSecondInfo>> queryByPage(String title, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<CmSecondInfo> cmSecondInfos = cmSecondInfoDao.queryAllByLimit(title);
        PaginationVo<CmSecondInfo> page = new PaginationVo<>(cmSecondInfos);
        return ResponseJson.success(page);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson insert(CmSecondInfo cmSecondInfo) {
        log.info("cmSecondInfo--------->" + cmSecondInfo.toString());
        cmSecondInfoDao.insert(cmSecondInfo);
        return ResponseJson.success();
    }


    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson update(CmSecondInfo cmSecondInfo) {
        log.info("cmSecondInfo--------->" + cmSecondInfo.toString());
        cmSecondInfoDao.update(cmSecondInfo);
        return ResponseJson.success();
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson deleteById(Integer id) {
        cmSecondInfoDao.deleteById(id);
        return ResponseJson.success();
    }
}
