package com.caimei365.manager.service.caimei.listener;

import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import com.alibaba.fastjson.JSON;
import com.caimei365.manager.dao.KeyWordDao;
import com.caimei365.manager.entity.caimei.CmKeywordInfo;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * Description
 *
 * @author : hzg
 * @date : 2023/11/28
 */
@Slf4j
@Service
public class LabelListener extends AnalysisEventListener<CmKeywordInfo> {

    @Resource
    private KeyWordDao keyWordDao;

    /**
     * 批处理阈值
     */
    private static final int BATCH_COUNT = 20;

    List<CmKeywordInfo> list = new ArrayList<>(BATCH_COUNT);

    @Override
    public void invoke(CmKeywordInfo data, AnalysisContext analysisContext) {
        log.info("解析一条数据====" + JSON.toJSONString(data));
        list.add(data);
        if (list.size() >= BATCH_COUNT) {
            save(list);
            list.clear();
        }
    }

    @Override
    public void doAfterAllAnalysed(AnalysisContext analysisContext) {
        save(list);
        log.info("数据解析完成");
    }

    public void save(List<CmKeywordInfo> infoList) {
        infoList.forEach(info -> {
            Integer keywordId = keyWordDao.getKeywordByName(info.getKeyword());
            if (null == keywordId) {
                info.setDynamicStatus(0);
                info.setParentLabel(0);
                keyWordDao.insertKeywordInfo(info);
            }
        });
    }
}
