package com.caimei365.manager.service.caimei.page.impl;

import com.caimei365.manager.dao.page.NewPageZoneDao;
import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.caimei.page.NewPageAdvertisementImage;
import com.caimei365.manager.entity.caimei.page.NewPageTopAdvertisementImage;
import com.caimei365.manager.entity.caimei.page.NewPageZone;
import com.caimei365.manager.entity.caimei.page.NewPageZoneImage;
import com.caimei365.manager.entity.caimei.product.Product;
import com.caimei365.manager.service.RedisService;
import com.caimei365.manager.service.caimei.page.NewPageZoneService;
import com.caimei365.manager.utils.GenerateUtils;
import com.github.pagehelper.PageHelper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

@Slf4j
@Service
public class NewPageZoneServiceImpl implements NewPageZoneService {

    @Resource
    private RedisService redisService;
    @Autowired
    private NewPageZoneDao zoneDao;


    @Override
    public ResponseJson<PaginationVo<NewPageZone>> getZoneList(int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<NewPageZone> zoneList = zoneDao.getZoneList();
        PaginationVo<NewPageZone> page = new PaginationVo<>(zoneList);
        return ResponseJson.success(page);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson saveZone(NewPageZone pageZone) {
        // 添加
        if (null == pageZone.getId()) {
            zoneDao.saveZone(pageZone);
        } else {
            zoneDao.updateZone(pageZone);
        }
        cleanRedisCache();
        return ResponseJson.success();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson delZone(Integer id) {
        zoneDao.delZone(id);
        zoneDao.delProducts(id);
        zoneDao.delImages(id);
        cleanRedisCache();
        return ResponseJson.success();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson updateEnabledStatus(Integer id, Integer status, Integer type) {
        zoneDao.updateEnabledStatus(id, status, type);
        cleanRedisCache();
        return ResponseJson.success();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson updateSort(Integer id, Integer sort) {
        zoneDao.updateSort(id, sort);
        cleanRedisCache();
        return ResponseJson.success();
    }

    @Override
    public ResponseJson<PaginationVo<Product>> getZoneProductList(Integer id, String shopName, Integer productId, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<Product> zoneList = zoneDao.getZoneProductList(id, shopName, productId);
        PaginationVo<Product> page = new PaginationVo<>(zoneList);
        return ResponseJson.success(page);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson delZoneProduct(Integer id, String ids) {
        List<Integer> list = new ArrayList<>();
        if (ids.contains(",")) {
            String[] split = ids.split(",");
            for (String str : split) {
                list.add(Integer.parseInt(str));
            }
        } else {
            list.add(Integer.parseInt(ids));
        }
        zoneDao.delZoneProduct(id, list);
        cleanRedisCache();
        return ResponseJson.success();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson addZoneProduct(Integer id, String ids) {
        List<Integer> list = new ArrayList<>();
        if (ids.contains(",")) {
            String[] split = ids.split(",");
            for (String str : split) {
                list.add(Integer.parseInt(str));
            }
        } else {
            list.add(Integer.parseInt(ids));
        }
        zoneDao.addZoneProduct(id, list);
        cleanRedisCache();
        return ResponseJson.success();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson updateProductSort(Integer id, Integer productId, Integer sort) {
        zoneDao.updateProductSort(id, productId, sort);
        cleanRedisCache();
        return ResponseJson.success();
    }

    @Override
    public ResponseJson<PaginationVo<NewPageZoneImage>> getZoneImageList(Integer id, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<NewPageZoneImage> zoneList = zoneDao.getZoneImageList(id);
        PaginationVo<NewPageZoneImage> page = new PaginationVo<>(zoneList);
        return ResponseJson.success(page);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson saveZoneImage(NewPageZoneImage pageZoneImage) {
        // 添加
        if (null == pageZoneImage.getImageId()) {
            zoneDao.saveZoneImage(pageZoneImage);
        } else {
            zoneDao.updateZoneImage(pageZoneImage);
        }
        cleanRedisCache();
        return ResponseJson.success();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson delZoneImage(Integer imageId) {
        zoneDao.delImageById(imageId);
        cleanRedisCache();
        return ResponseJson.success();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson updateImageSort(Integer imageId, Integer sort) {
        zoneDao.updateImageSort(imageId, sort);
        cleanRedisCache();
        return ResponseJson.success();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson updateImageStatus(Integer imageId, Integer status, Integer type) {
        zoneDao.updateImageStatus(imageId, status, type);
        cleanRedisCache();
        return ResponseJson.success();
    }

    @Override
    public ResponseJson<NewPageZoneImage> getZoneImageForm(Integer imageId) {
        return ResponseJson.success(zoneDao.getImage(imageId));
    }

    @Override
    public ResponseJson<PaginationVo<Product>> getRecommendList(String shopName, Integer productId, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<Product> products = zoneDao.getRecommendList(shopName, productId);
        PaginationVo<Product> page = new PaginationVo<>(products);
        return ResponseJson.success(page);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson addRecommendProduct(String ids) {
        List<Integer> list = new ArrayList<>();
        if (ids.contains(",")) {
            String[] split = ids.split(",");
            for (String str : split) {
                list.add(Integer.parseInt(str));
            }
        } else {
            list.add(Integer.parseInt(ids));
        }
        zoneDao.addRecommendProduct(list);
        cleanRedisCache();
        return ResponseJson.success();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson recommendDel(String ids) {
        List<Integer> list = new ArrayList<>();
        if (ids.contains(",")) {
            String[] split = ids.split(",");
            for (String str : split) {
                list.add(Integer.parseInt(str));
            }
        } else {
            list.add(Integer.parseInt(ids));
        }
        zoneDao.recommendDel(list);
        cleanRedisCache();
        return ResponseJson.success();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson recommendSort(Integer productId, Integer sort) {
        zoneDao.recommendSort(productId, sort);
        cleanRedisCache();
        return ResponseJson.success();
    }

    @Override
    public ResponseJson<PaginationVo<NewPageAdvertisementImage>> advertisementList(int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<NewPageAdvertisementImage> images = zoneDao.advertisementList();
        PaginationVo<NewPageAdvertisementImage> page = new PaginationVo<>(images);
        return ResponseJson.success(page);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson saveAdvertisement(NewPageAdvertisementImage image) {
        if (null == image.getId()) {
            zoneDao.saveAdvertisement(image);
        } else {
            zoneDao.updateAdvertisement(image);
        }
        cleanRedisCache();
        return ResponseJson.success();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson advertisementSort(Integer id, Integer sort) {
        zoneDao.advertisementSort(id, sort);
        cleanRedisCache();
        return ResponseJson.success();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson advertisementDel(Integer id) {
        zoneDao.advertisementDel(id);
        cleanRedisCache();
        return ResponseJson.success();
    }

    @Override
    public ResponseJson<PaginationVo<NewPageTopAdvertisementImage>> topAdvertisementList(int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<NewPageTopAdvertisementImage> images = zoneDao.topAdvertisementList();
        PaginationVo<NewPageTopAdvertisementImage> page = new PaginationVo<>(images);
        return ResponseJson.success(page);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson saveTopAdvertisement(NewPageTopAdvertisementImage image) {
        if (null == image.getId()) {
            zoneDao.saveTopAdvertisement(image);
        } else {
            zoneDao.updateTopAdvertisement(image);
        }
        cleanRedisCache();
        return ResponseJson.success();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson topAdvertisementDel(Integer id) {
        zoneDao.delTopAdvertisement(id);
        cleanRedisCache();
        return ResponseJson.success();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson updateTopStatus(Integer id, Integer status, Integer type) {
        zoneDao.updateTopStatus(id, status, type);
        cleanRedisCache();
        return ResponseJson.success();
    }

    @Override
    public ResponseJson<NewPageAdvertisementImage> advertisementForm(Integer id) {
        return ResponseJson.success(zoneDao.getAdvertisementForm(id));
    }

    @Override
    public ResponseJson<NewPageTopAdvertisementImage> topAdvertisementForm(Integer id) {
        return ResponseJson.success(zoneDao.getTopAdvertisementForm(id));
    }

    @Override
    public ResponseJson<PaginationVo<Product>> selectProductList(Integer id, Integer productId, String shopName, String productName, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<Product> products = zoneDao.selectProductList(id, productId, shopName, productName);
        PaginationVo<Product> page = new PaginationVo<>(products);
        return ResponseJson.success(page);
    }

    @Override
    public ResponseJson<PaginationVo<Product>> recommendProductList(Integer productId, String shopName, String productName, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<Product> products = zoneDao.recommendProductList(productId, shopName, productName);
        PaginationVo<Product> page = new PaginationVo<>(products);
        return ResponseJson.success(page);
    }

    public void cleanRedisCache() {
        //首页缓存
        redisService.removePattern("getHomeCommodityData*");
        // 重新生成静态首页
        GenerateUtils.generateHome();
    }
}
