package com.caimei365.manager.service.caimei.product.impl;

import com.caimei365.manager.dao.AddressMapper;
import com.caimei365.manager.dao.product.ProductMapper;
import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.caimei.AddressSelectVo;
import com.caimei365.manager.entity.caimei.brand.CmBrand;
import com.caimei365.manager.entity.caimei.product.CmSecondHandDetail;
import com.caimei365.manager.entity.caimei.product.Product;
import com.caimei365.manager.entity.caimei.product.ProductImagePo;
import com.caimei365.manager.service.caimei.product.ProductService;
import com.github.pagehelper.PageHelper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

@Service
@Slf4j
public class ProductServiceImpl implements ProductService {

    @Resource
    private ProductMapper productMapper;
    @Resource
    private AddressMapper addressMapper;

    @Override
    public ResponseJson<PaginationVo<Product>> secondProductList(Product product, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<Product> productList = productMapper.findSecondList(product);
        PaginationVo<Product> paginationVo = new PaginationVo<>(productList);
        return ResponseJson.success(paginationVo);
    }

    @Override
    public ResponseJson<List<CmBrand>> brandList() {
        List<CmBrand> brands = productMapper.brandList();
        brands.add(new CmBrand().setName("其他").setId(161));
        return ResponseJson.success(brands);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson updateStatus(Product product) {
        productMapper.updateStatus(product);
        if (2 == product.getValidFlag()) {
            productMapper.updateOnlineDate(product);
        }
        return ResponseJson.success();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson updateShop(Product product) {
        productMapper.updateShop(product);
        productMapper.updateSecondDetail(product);
        return ResponseJson.success();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson saveSecond(CmSecondHandDetail product) {
        if (null == product.getProductId()) {
            return ResponseJson.error("商品Id不能为空");
        }
        productMapper.updateSku(product);
        // 地址
        Integer townId = product.getTownId();
        String provinceCityDistrict = "";
        if (null != townId) {
            AddressSelectVo addByTownId = addressMapper.getAddByTownId(townId);
            if (null != addByTownId) {
                String province = addByTownId.getProvince();
                String city = addByTownId.getCity();
                String town = addByTownId.getTown();
                provinceCityDistrict = province + "/" + city + "/" + town;
                product.setProvinceCityDistrict(provinceCityDistrict);
            }
        }
        productMapper.updateSecond(product);

        productMapper.delProductImages(product);
        if (null != product.getProductImages()) {
            List<String> productImages = product.getProductImages();
            for (int i = 0; i < productImages.size(); i++) {
                ProductImagePo imagePo = new ProductImagePo();
                imagePo.setProductId(product.getProductId());
                imagePo.setShopId(product.getShopId());
                imagePo.setImage(productImages.get(i));
                int flag = 0 == i ? 1 : 0;
                imagePo.setMainFlag(flag);
                if (flag == 1) {
                    product.setMainImage(productImages.get(i));
                    productMapper.updateProduct(product);
                }
                productMapper.insertProductImage(imagePo);
            }
        }
        return ResponseJson.success();
    }

    @Override
    public ResponseJson<CmSecondHandDetail> secondDetail(Integer productId) {
        CmSecondHandDetail detail = productMapper.findSecondDetail(productId);
        detail.setProductImages(productMapper.findProductImages(productId));
        return ResponseJson.success(detail);
    }
}
