package com.caimei365.manager.service.caimei.providers.impl;

import java.io.File;
import java.util.Arrays;
import java.util.Date;
import java.util.List;

import com.caimei.utils.AppUtils;
import com.caimei.utils.StringUtil;
import com.caimei365.manager.FastDFS.FastDFSClient;
import com.caimei365.manager.config.utils.DateUtil;
import com.caimei365.manager.dao.CmRelatedImageMapper;
import com.caimei365.manager.dao.providers.CmProvidersContractMapper;
import com.caimei365.manager.dao.providers.CmProvidersMapper;
import com.caimei365.manager.dao.user.UserMapper;
import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.caimei.CmRelatedImage;
import com.caimei365.manager.entity.caimei.cmUser.CmClub;
import com.caimei365.manager.entity.caimei.providers.ProviderTask;
import com.caimei365.manager.entity.caimei.providers.ServiceProviderModel;
import com.caimei365.manager.entity.caimei.cmUser.User;
import com.caimei365.manager.entity.caimei.product.Product;
import com.caimei365.manager.entity.caimei.providers.CmProviderTeam;
import com.caimei365.manager.entity.caimei.providers.CmProvidersContract;
import com.caimei365.manager.entity.po.UploadFilePo;
import com.caimei365.manager.service.caimei.providers.CmProvidersContractService;
import com.caimei365.manager.service.caimei.providers.CmProvidersService;
import com.caimei365.manager.utils.ImageUtils;
import com.caimei365.manager.utils.Md5Util;
import com.caimei365.manager.utils.StringSplitUtils;
import com.github.pagehelper.PageHelper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * Service业务层处理
 *
 * @author Kaick
 * @date 2023-12-12
 */
@Slf4j
@Service
public class CmProvidersServiceImpl implements CmProvidersService {
    @Resource
    private CmProvidersMapper cmProvidersMapper;

    @Resource
    private CmProvidersContractMapper cmProvidersContractMapper;
    @Resource
    private CmProvidersContractService cmProvidersContractService;

    @Resource
    private CmRelatedImageMapper cmRelatedImageMapper;
    @Resource
    private UserMapper userMapper;


    /**
     * 通过对象查询列表
     *
     * @param cmProviders
     * @return
     */
    @Override
    public List<ServiceProviderModel> getCmProvidersList(ServiceProviderModel cmProviders) {
        return cmProvidersMapper.getCmProvidersList(cmProviders);
    }

    /**
     * 通过Id查询
     *
     * @param id 主键
     * @return
     */
    @Override
    public ServiceProviderModel getCmProvidersById(Integer id) {
        ServiceProviderModel cmProvidersById = cmProvidersMapper.getCmProvidersById(id);
        cmProvidersById.setTextRelateds(cmRelatedImageMapper.getRelatedImageList(new CmRelatedImage().setType("2").setAuthorId(cmProvidersById.getServiceProviderId().toString())));
        cmProvidersById.setInfoRelateds(cmRelatedImageMapper.getRelatedImageList(new CmRelatedImage().setType("3").setAuthorId(cmProvidersById.getServiceProviderId().toString())));
        return cmProvidersById;
    }

    /**
     * 通过对象查询
     *
     * @param cmProviders
     * @return
     */
    @Override
    public ServiceProviderModel getByCmProviders(ServiceProviderModel cmProviders) {
        ServiceProviderModel providers = cmProvidersMapper.getByCmProviders(cmProviders);
        providers.setTextRelateds(cmRelatedImageMapper.getRelatedImageList(new CmRelatedImage().setType("2").setAuthorId(cmProviders.getServiceProviderId().toString())));
        providers.setInfoRelateds(cmRelatedImageMapper.getRelatedImageList(new CmRelatedImage().setType("3").setAuthorId(cmProviders.getServiceProviderId().toString())));
        return providers;
    }


    /**
     * 新增
     *
     * @param cmProviders
     * @return 结果
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public int addCmProviders(ServiceProviderModel cmProviders) {
        if (null == cmProviders.getServiceProviderId()) {
            User user = new User();
            user.setMobile(cmProviders.getMobile()).setBindMobile(cmProviders.getMobile()).setUserName(cmProviders.getLinkMan()).setName(cmProviders.getName()).setServiceProviderStatus(90).setUserIdentity(1).setRegisterUserTypeID("-1").setRegisterTime(DateUtil.getDateTime()).setValidFlag("1").setPassword(Md5Util.md5(cmProviders.getPassword()));
            userMapper.addUser(user);
            cmProviders.setUserId(Integer.valueOf(user.getUserID()));
            String qualificationId = "CMFW0" + cmProviders.getServiceLevel();
            if (0 == cmProvidersMapper.getCount(null)) {
                qualificationId = qualificationId + "000001";
            } else {
                int num = Integer.parseInt(cmProvidersMapper.getByCmProviders(null).getQualificationId().substring(6));
                num++; // 每次加1
                // 使用字符串格式化保持位数不变，总共有6位，使用0进行填充
                qualificationId = qualificationId + String.format("%06d", num);
            }
            cmProviders.setQualificationId(qualificationId);
            cmProviders.setStatus(90);
            cmProviders.setAddTime(new Date());
            cmProvidersMapper.addCmProviders(cmProviders);   //新增服务商
            String providersId = cmProviders.getServiceProviderId().toString();
            cmProviders.getContract().setServiceProviderId(Integer.valueOf(providersId));
            cmProviders.getContract().setCreateBy(cmProviders.getCreateBy());
            cmProvidersContractService.addCmProvidersContract(cmProviders.getContract()); //新增服务商合同
            for (CmRelatedImage textRelatedImage : cmProviders.getTextRelateds()) {
                cmRelatedImageMapper.addCmRelatedImage(new CmRelatedImage().setType("2").setAuthorId(providersId).setImage(textRelatedImage.getImage()).setFileName(textRelatedImage.getFileName()));      //新增服务商简介图
            }
            for (CmRelatedImage infoRelatedImage : cmProviders.getInfoRelateds()) {
                cmRelatedImageMapper.addCmRelatedImage(new CmRelatedImage().setType("3").setAuthorId(providersId).setImage(infoRelatedImage.getImage()).setFileName(infoRelatedImage.getFileName()));      //新增服务资料文件
            }
            return 1;
        } else {
            User user = new User();
            user.setMobile(cmProviders.getMobile()).setBindMobile(cmProviders.getMobile()).setUserName(cmProviders.getLinkMan()).setName(cmProviders.getName()).setValidFlag(cmProviders.getStatus() == 90 ? "1" : "0");
            userMapper.updateUser(user);
            String qualificationId = new StringBuffer(cmProviders.getQualificationId()).replace(5, 6, cmProviders.getServiceLevel().toString()).toString();
            cmProviders.setQualificationId(qualificationId);
            CmRelatedImage cmRelatedImage = new CmRelatedImage().setType("3").setAuthorId(cmProviders.getServiceProviderId().toString());
            cmRelatedImageMapper.delCmRelatedImage(cmRelatedImage);      //删除旧服务资料文件
            cmRelatedImage.setType("2");
            cmRelatedImageMapper.delCmRelatedImage(cmRelatedImage);      //删除旧服务商简介图
            for (CmRelatedImage textRelatedImage : cmProviders.getTextRelateds()) {
                cmRelatedImageMapper.addCmRelatedImage(cmRelatedImage.setImage(textRelatedImage.getImage()).setFileName(textRelatedImage.getFileName()));      //新增服务商简介图
            }
            cmRelatedImage.setType("3");
            for (CmRelatedImage infoRelatedImage : cmProviders.getInfoRelateds()) {
                cmRelatedImageMapper.addCmRelatedImage(cmRelatedImage.setImage(infoRelatedImage.getImage()).setFileName(infoRelatedImage.getFileName()));       //新增服务资料文件
            }
            cmProvidersMapper.updateCmProviders(cmProviders);
            CmProvidersContract contract = cmProvidersContractMapper.getByCmProvidersContract(new CmProvidersContract().setServiceProviderId(cmProviders.getServiceProviderId()));
            contract.setFlag(false);//更改新增标识
            cmProvidersContractService.addCmProvidersContract(contract); //新增服务商合同
            return 1;
        }
    }

    /**
     * 修改
     *
     * @param cmProviders
     * @return 结果
     */
    @Override
    public void updateCmProviders(ServiceProviderModel cmProviders) {
        if (null != cmProviders.getStatus()) {
            userMapper.updateCmproviderStatus(cmProviders);
        }
        cmProvidersMapper.updateCmProviders(cmProviders);
    }


    /**
     * 下載圖片
     */
    @Override
    public void downloadImage(String ids, Integer type, HttpServletRequest request, HttpServletResponse response) throws Exception {
        // 将图片压缩成zip文件
        List<UploadFilePo> uploadFileList = cmProvidersMapper.getProvidersUploadFileList(ids, type);
        String imageZipPath = ImageUtils.createImageZip(uploadFileList, type);
        FastDFSClient.download(request, response, imageZipPath, imageZipPath.substring(imageZipPath.lastIndexOf("/")));
        // 删除临时文件夹
        String tempPath = imageZipPath.substring(0, imageZipPath.lastIndexOf("/"));
        log.info("【图片压缩包】,删除图片压缩包文件夹:" + ImageUtils.deleteFile(new File(tempPath)));
    }


    @Override
    public ResponseJson<PaginationVo<Product>> getProviderProducts(Integer providerId, String shopName, String productName, Integer productId, Integer shopId, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        // 供应商商品
        List<Product> productList = cmProvidersMapper.getProductList(providerId, shopName, productName, productId, shopId);
        productList.forEach(product -> {
            if (StringUtil.isNotBlank(product.getMainImage())) {
                product.setMainImage(AppUtils.getImageURL("product", product.getMainImage(), 0, "wwwServer"));
                if (!product.getMainImage().contains("https")) {
                    product.setMainImage("https://admin.caimei365.com/" + product.getMainImage());
                }
            }
        });
        PaginationVo<Product> page = new PaginationVo<>(productList);
        return ResponseJson.success(page);
    }

    @Override
    public ResponseJson addProvidersProducts(Integer providerId, String productIds) {
        List<String> strings = Arrays.asList(productIds.split(","));
        cmProvidersMapper.addProviderProduct(providerId, strings);
        return ResponseJson.success();
    }

    @Override
    public ResponseJson<PaginationVo<Product>> getProviderProductList(Integer providerId, String productName, Integer productId, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        // 供应商商品
        List<Product> productList = cmProvidersMapper.getProviderProductList(providerId, productName, productId);
        productList.forEach(product -> {
            if (StringUtil.isNotBlank(product.getMainImage())) {
                product.setMainImage(AppUtils.getImageURL("product", product.getMainImage(), 0, "wwwServer"));
                if (!product.getMainImage().contains("https")) {
                    product.setMainImage("https://admin.caimei365.com/" + product.getMainImage());
                }
            }
        });
        PaginationVo<Product> page = new PaginationVo<>(productList);
        return ResponseJson.success(page);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson delProvidersProducts(Integer providerId, Integer productId) {
        cmProvidersMapper.delProviderProduct(providerId, productId);
        return ResponseJson.success();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson updatePassWord(Integer userId, String password) {
        password = Md5Util.md5(password);
        cmProvidersMapper.updatePass(userId, password);
        return ResponseJson.success();
    }

    @Override
    public ResponseJson<PaginationVo<CmProviderTeam>> providerTeam(int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<CmProviderTeam> teams = cmProvidersMapper.getProviderTeam();
        PaginationVo<CmProviderTeam> page = new PaginationVo<>(teams);
        return ResponseJson.success(page);
    }

    @Override
    public ResponseJson<PaginationVo<CmClub>> clubList(Integer spId, Integer clubId, String name, String linkMan, String bindMobile, int pageNum, int pageSize) {
        CmClub club = new CmClub();
        club.setSpId(spId).setClubId(clubId).setName(name).setLinkMan(linkMan).setBindMobile(bindMobile);
        PageHelper.startPage(pageNum, pageSize);
        List<CmClub> clubs = cmProvidersMapper.findClub(club);
        PaginationVo<CmClub> page = new PaginationVo<>(clubs);
        return ResponseJson.success(page);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson addTeam(CmProviderTeam team) {
        if (null == team.getTeamId()) {
            cmProvidersMapper.addTeam(team);
            cmProvidersMapper.addGroup(team.getTeamId(), StringSplitUtils.strToList(team.getLeaderId().toString()));
        } else {
            cmProvidersMapper.updateTeam(team);
        }
        return ResponseJson.success();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson delTeam(Integer id) {
        cmProvidersMapper.delTeam(id);
        cmProvidersMapper.delTeamGroup(id);
        return ResponseJson.success();
    }

    @Override
    public ResponseJson<PaginationVo<ServiceProviderModel>> groupList(Integer id, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<ServiceProviderModel> group = cmProvidersMapper.groupList(id);
        PaginationVo<ServiceProviderModel> page = new PaginationVo<>(group);
        return ResponseJson.success(page);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson delGroup(Integer teamId, Integer spId) {
        cmProvidersMapper.delGroup(teamId, spId);
        return ResponseJson.success();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson addGroup(Integer teamId, String spId) {
        cmProvidersMapper.addGroup(teamId, StringSplitUtils.strToList(spId));
        return ResponseJson.success();
    }

    @Override
    public ResponseJson<PaginationVo<ServiceProviderModel>> addGroups(String mobile, String name, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<ServiceProviderModel> group = cmProvidersMapper.addGroups(mobile, name);
        PaginationVo<ServiceProviderModel> page = new PaginationVo<>(group);
        return ResponseJson.success(page);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson updateLeader(CmProviderTeam team) {
        cmProvidersMapper.updateLeader(team);
        return ResponseJson.success();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson addTask(ProviderTask task) {
        if (null == task.getId()) {
            cmProvidersMapper.addTask(task);
        } else {
            cmProvidersMapper.updateTask(task);
        }
        return ResponseJson.success();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson assignTask(Integer id, String serviceProviderIds) {
        cmProvidersMapper.assignTask(id, StringSplitUtils.strToList(serviceProviderIds));
        return ResponseJson.success();
    }

    @Override
    public ResponseJson<PaginationVo<ProviderTask>> taskList(String shopName,int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<ProviderTask> tasks = cmProvidersMapper.taskList(shopName);
        PaginationVo<ProviderTask> page = new PaginationVo<>(tasks);
        return ResponseJson.success(page);
    }

    @Override
    public ResponseJson<PaginationVo<ServiceProviderModel>> taskProviderList(Integer taskId, String name, String mobile, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<ServiceProviderModel> providers = cmProvidersMapper.taskProviderList(taskId, name, mobile);
        PaginationVo<ServiceProviderModel> page = new PaginationVo<>(providers);
        return ResponseJson.success(page);
    }

    @Override
    public ResponseJson<PaginationVo<ServiceProviderModel>> providerReceiveList(Integer taskId, String name, String mobile, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<ServiceProviderModel> providers = cmProvidersMapper.providerReceiveList(taskId, name, mobile);
        PaginationVo<ServiceProviderModel> page = new PaginationVo<>(providers);
        return ResponseJson.success(page);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson taskProviderDel(Integer taskId, Integer serviceProviderId) {
        cmProvidersMapper.taskProviderDel(taskId, serviceProviderId);
        return ResponseJson.success();
    }

    @Override
    public ResponseJson<ProviderTask> taskDetail(Integer taskId) {
        ProviderTask taskDetail = cmProvidersMapper.getTaskDetail(taskId);
        taskDetail.setMainImage(AppUtils.getImageURL("product", taskDetail.getMainImage(), 0, "wwwServer"));
        return ResponseJson.success(taskDetail);
    }

    @Override
    public ResponseJson<PaginationVo<Product>> productList(String name, String shopName, Integer productId, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<Product> products = cmProvidersMapper.getTaskProducts(name, shopName, productId);
        products.forEach(product -> {
            if (StringUtil.isNotBlank(product.getMainImage())) {
                product.setMainImage(AppUtils.getImageURL("product", product.getMainImage(), 0, "wwwServer"));
                if (!product.getMainImage().contains("https")) {
                    product.setMainImage("https://admin.caimei365.com/" + product.getMainImage());
                }
            }
        });
        PaginationVo<Product> page = new PaginationVo<>(products);
        return ResponseJson.success(page);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public ResponseJson taskAudit(Integer taskId, Integer serviceProviderId, Integer auditStatus) {
        cmProvidersMapper.auditTask(taskId, serviceProviderId, auditStatus);
        return ResponseJson.success();
    }

}



