package com.caimei365.manager.service.caimei.user.impl;

import com.caimei.utils.AppUtils;
import com.caimei.utils.StringUtils;
import com.caimei365.manager.dao.user.CmBehaviorRecordDao;
import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.caimei.CmBehaviorRecord;
import com.caimei365.manager.entity.caimei.CmPageType;
import com.caimei365.manager.entity.caimei.ReturnEntity;
import com.caimei365.manager.service.caimei.user.CmBehaviorRecordService;
import com.github.pagehelper.PageHelper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.concurrent.atomic.AtomicReference;
import java.util.stream.Collectors;

/**
 * Description
 *
 * @author : Charles
 * @date : 2023/3/15
 */
@Slf4j
@Service
public class CmBehaviorRecordServiceImpl implements CmBehaviorRecordService {

    @Resource
    private CmBehaviorRecordDao cmBehaviorRecordDao;

    /**
     * 获取父标签
     *
     * @param keyword
     * @return
     */
    @Override
    public ResponseJson getKeyword(String keyword) {
        return ResponseJson.success(cmBehaviorRecordDao.getkeyword(keyword));
    }

    /**
     * 获取页面标签
     *
     * @param pageLabels
     * @return
     */
    @Override
    public ResponseJson<List<CmPageType>> getPageType(String pageLabels) {
        return ResponseJson.success(cmBehaviorRecordDao.getPageType(pageLabels));
    }


    /**
     * 用户行为列表
     * @param cmBehaviorRecord
     * @param pageNum
     * @param pageSize
     * @return
     */
    @Override
    public ResponseJson<PaginationVo<CmBehaviorRecord>> list(CmBehaviorRecord cmBehaviorRecord,Integer pageNum, Integer pageSize) {
        List<CmBehaviorRecord> list = null;
        List<String> labels = new ArrayList<>();
        String behaviorType = "";
        if (StringUtils.isNotBlank(cmBehaviorRecord.getLabel())) {
            if (cmBehaviorRecord.getLabel().contains(",")) {
                String[] split = cmBehaviorRecord.getLabel().split(",");
                for (String str : split) {
                    labels.add(str);
                }
            } else {
                labels.add(cmBehaviorRecord.getLabel());
            }
        }
        cmBehaviorRecord.setLabels(labels);
        //"深圳艾斯佰丽生物科技有限公司".equals(cmBehaviorRecord.getSpName())
        if ("深圳艾斯佰丽生物科技有限公司".equals(cmBehaviorRecord.getRelevanceShop())) {
            behaviorType = "2";
        }
        cmBehaviorRecord.setBehaviorType(behaviorType);
        PageHelper.startPage(pageNum, pageSize);
        if (cmBehaviorRecord.getTodayType() == 0) {
            // 今日数据
            list = cmBehaviorRecordDao.findListToday(cmBehaviorRecord);
        } else {
            // 过往数据
            list = cmBehaviorRecordDao.findList(cmBehaviorRecord);
        }
        // 总时长
        for (CmBehaviorRecord record : list) {
            String time = calculationTime(record.getAccessDuration());
            record.setAccessDuration(time);
        }
        PaginationVo<CmBehaviorRecord> pageData = new PaginationVo<>(list);
        return ResponseJson.success(pageData);
    }

    /**
     * 导出今日数据
     *
     * @param cmBehaviorRecord
     * @return
     */
    @Override
    public List<CmBehaviorRecord> exportExcel(CmBehaviorRecord cmBehaviorRecord) {
        List<String> labels = new ArrayList<>();
        String behaviorType = "";
        if (StringUtils.isNotBlank(cmBehaviorRecord.getLabel())) {
            if (cmBehaviorRecord.getLabel().contains(",")) {
                String[] split = cmBehaviorRecord.getLabel().split(",");
                for (String str : split) {
                    labels.add(str);
                }
            } else {
                labels.add(cmBehaviorRecord.getLabel());
            }
        }
        cmBehaviorRecord.setLabels(labels);
        //"深圳艾斯佰丽生物科技有限公司".equals(cmBehaviorRecord.getSpName())
        if ("深圳艾斯佰丽生物科技有限公司".equals(cmBehaviorRecord.getRelevanceShop())) {
            behaviorType = "2";
        }
        cmBehaviorRecord.setBehaviorType(behaviorType);
        List<CmBehaviorRecord> list = null;
        if (cmBehaviorRecord.getTodayType() == 0) {
            // 当天数据
            list = cmBehaviorRecordDao.findListToday(cmBehaviorRecord);
        } else {
            // 过往数据
            cmBehaviorRecord.setExportType(1);
            list = cmBehaviorRecordDao.findList(cmBehaviorRecord);
        }
        list.forEach(t -> {
            if ("0".equals(t.getAccessClient())) {
                t.setAccessClient("网站");
            } else {
                t.setAccessClient("小程序");
            }

            if ("1".equals(t.getCompanyType())) {
                t.setCompanyType("游客");
            } else if ("2".equals(t.getCompanyType())) {
                t.setCompanyType("机构");
                t.setReId(null != t.getClubId() ? t.getClubId() : null);
            } else {
                t.setCompanyType("供应商");
                t.setReId(null != t.getShopId() ? t.getShopId() : null);
            }
            // 总时长
            String time = calculationTime(t.getAccessDuration());
            t.setAccessDuration(time);
        });
        return list;
    }

    /**
     * 查看详情 todo 跟list共用接口，要拆分
     * @param cmBehaviorRecord
     * @param pageNum
     * @param pageSize
     * @return
     */
    @Override
    public ResponseJson<Map<String, Object>> recordList(CmBehaviorRecord cmBehaviorRecord, Integer pageNum, Integer pageSize) {
        Map<String, Object> map = new HashMap<>();
        PageHelper.startPage(pageNum, pageSize);
        // 详情
        List<CmBehaviorRecord> recordList = cmBehaviorRecordDao.recordList(cmBehaviorRecord);
        // 访问来源
        List<CmBehaviorRecord> reginList = cmBehaviorRecordDao.selRegion(cmBehaviorRecord.getAccessDate());
        // 供应商信息
        List<CmBehaviorRecord> shopNameList = cmBehaviorRecordDao.behaviorShopNameList();
        // 标签总结
        List<ReturnEntity> label = new ArrayList<>();
        AtomicReference<Integer> returnId = new AtomicReference<>(0);
        // 计算访问时长，填入信息
        recordList.forEach(r -> {
            r.setProductImage(AppUtils.getImageURL("product", r.getProductImage(), 0, ""));
            if (!r.getProductImage().contains("https")) {
                r.setProductImage("https://admin.caimei365.com/" + r.getProductImage());
            }
            String time = calculationTime(r.getAccessDuration());
            r.setAccessDuration(time);
            String decode = null;
            try {
                decode = URLDecoder.decode(r.getPagePath(),"UTF-8");
            } catch (UnsupportedEncodingException e) {
                e.printStackTrace();
            }
            r.setPagePath(decode);

            SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm");
            String s = "";
            try {
                s = simpleDateFormat.format(simpleDateFormat.parse(r.getAccessTime()));
            } catch (ParseException e) {
                e.printStackTrace();
            }
            for (CmBehaviorRecord record : reginList) {
                String format = "";
                try {
                    format = simpleDateFormat.format(simpleDateFormat.parse(record.getAccessTime()));
                } catch (ParseException e) {
                    e.printStackTrace();
                }
                if (r.getIp().equals(record.getIp()) && format.equals(s)) {
                    record.setAccessSource(record.getAccessSource());
                }
            }
            // 供应商显示
            if (shopNameList.size() > 0) {
                String shopName = "";
                for(CmBehaviorRecord record :shopNameList) {

                    if (r.getRecordId().equals(record.getRecordId())) {
                        shopName += record.getName();
                    }

                }
                r.setRelevanceShop(shopName);
            }
            if ("6".equals(r.getPageType()) || "8".equals(r.getPageType()) || "9".equals(r.getPageType()) || "11".equals(r.getPageType())) {
                if(StringUtils.isNotBlank(r.getPageLabel()) && StringUtils.isNotEmpty(r.getPageLabel()) && !label.contains(r.getPageLabel())) {
                    ReturnEntity retuenEntity = new ReturnEntity();
                    if (r.getPageLabel().contains(",")) {
                        String[] split = r.getPageLabel().split(",");
                        for (String str : split) {
                            List<String> collect = label.stream().map(ReturnEntity::getValue).collect(Collectors.toList());
                            if (StringUtils.isNotBlank(str) &&  !collect.contains(str)) {
                                retuenEntity = new ReturnEntity();
                                returnId.updateAndGet(v -> v + 1);
                                retuenEntity.setId(returnId.get().toString());
                                retuenEntity.setValue(str);
                                label.add(retuenEntity);
                            }
                        }
                    } else {
                        List<String> collect = label.stream().map(ReturnEntity::getValue).collect(Collectors.toList());
                        if (!collect.contains(r.getPageLabel())) {
                            returnId.updateAndGet(v -> v + 1);
                            retuenEntity.setId(returnId.get().toString());
                            retuenEntity.setValue(r.getPageLabel());
                            label.add(retuenEntity);
                        }
                    }
                }
            }
        });
        PaginationVo<CmBehaviorRecord> pageData = new PaginationVo<>(recordList);
        map.put("page", pageData);
        map.put("label", label);
        return ResponseJson.success(map);
    }

    /**
     * 标签库数据
     *
     * @return 返回
     */
    @Override
    public ResponseJson searchList() {

        return ResponseJson.success(cmBehaviorRecordDao.searchList());
    }

    @Override
    public ResponseJson<PaginationVo<CmBehaviorRecord>> prodcutCount(Integer productId, String beginTime, String endTime, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<CmBehaviorRecord> records = cmBehaviorRecordDao.getProductCountList(productId,beginTime,endTime);
        records.forEach(r->{
            r.setProductImage(AppUtils.getImageURL("product", r.getProductImage(), 0, ""));
            if (!r.getProductImage().contains("https")) {
                r.setProductImage("https://admin.caimei365.com/" + r.getProductImage());
            }
        });
        PaginationVo<CmBehaviorRecord> pageData = new PaginationVo<>(records);
        return ResponseJson.success(pageData);
    }

    @Override
    public ResponseJson<PaginationVo<CmBehaviorRecord>> prodcutCountDetail(Integer productId, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<CmBehaviorRecord> records = cmBehaviorRecordDao.getProductCountDetail(productId);
        for (CmBehaviorRecord record : records) {
            String time = calculationTime(record.getAccessDuration());
            record.setAccessDuration(time);
        }
        PaginationVo<CmBehaviorRecord> pageData = new PaginationVo<>(records);
        return ResponseJson.success(pageData);
    }

    /**
     * 时间计算
     * @param recordTime
     * @return
     */
    public String calculationTime(String recordTime){
        double doc = Double.parseDouble(recordTime);
        int num = (int)doc;
        //小时
        int HH = 0;
        // 分钟
        int mm = 0;
        //秒
        int ss = 0;
        int item = num / 1000;
        if ((item / 60) >0) {
            mm = item / 60;
            ss = item % 60;
        } else {
            ss = item;
        }
        if ((mm / 60) >0) {
            HH = mm / 60;
            mm = mm % 60;
        }
        String  str= HH+":"+mm+":"+ss;
        SimpleDateFormat dateFormat = new SimpleDateFormat("HH:mm:ss");
        Date parse = null;
        try {
            parse = dateFormat.parse(str);
        } catch (ParseException e) {
            e.printStackTrace();
        }
        return dateFormat.format(parse);
    }
}
