package com.caimei365.manager.utils;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.core.env.Environment;
import org.springframework.core.io.ClassPathResource;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;
import javax.annotation.Resource;
import java.io.*;
import java.util.*;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

@Component
public class FFMPEG {
    @Resource
    private Environment environment;
    private static String config;
    private static String ffmepgPath = "/usr/bin/ffmpeg";
    private static String logoPath = "/mnt/newdatadrive/data/runtime/jar-instance/manager-api/logo/logo.png";

    @PostConstruct
    public void setValue() {
        config = environment.getProperty("cm.config");
        if ("dev".equals(config)) {
            ffmepgPath = "E:\\kaick\\tools\\idmZIP\\ffmpeg-6.1-essentials_build\\bin\\ffmpeg.exe";
            logoPath = "D\\\\:logo.png";
        }
    }

    /**
     * 日志对象
     */
    private static Logger logger = LoggerFactory.getLogger(FFMPEG.class);

    public static String dealString(String str) {
        Matcher m = Pattern.compile("^frame=.*").matcher(str);
        String msg = "";
        while (m.find()) {
            msg = m.group();
        }
        return msg;
    }

    /**
     * 如果是数字就是成功的时间(秒数)
     *
     * @param str
     * @return
     */
    public static boolean isNumeric(String str) {
        Pattern pattern = Pattern.compile("[0-9]*");
        Matcher isNum = pattern.matcher(str);
        if (!isNum.matches()) {
            return false;
        }
        return true;
    }

    /**
     * 如果返回不是null的值就是成功(值为转换用时单位:秒)
     *
     * @param instr
     * @return
     */
    public static String returnSecond(String instr) {
        String returnValue = null;
        if (null != instr) {
            String[] a = instr.split("\\.");
            String[] b = a[0].split(":");
            int returnNumber = 0;
            if (null != instr && b[0].length() != 0) {
                returnNumber = Integer.valueOf(b[0]) * 60 * 60 + Integer.valueOf(b[1]) * 60 + Integer.valueOf(b[2]);
                returnValue = String.valueOf(returnNumber);
            } else {
                returnValue = null;
            }
        }
        return returnValue;
    }

    /**
     * 获取视频格式(转码前的格式和转码后的格式都可以调用)
     *
     * @param outputPath
     * @return
     */
    public static String returnVideoFormat(String outputPath) {
        return outputPath.substring(outputPath.lastIndexOf(".") + 1);
    }

    /**
     * @ HashMap<String,String> dto 参数传递对象<br>
     * dto中包含的参数<br>
     * (必填)1.ffmpeg_path:ffmpeg执行文件地址,如 d:\\ffmpeg\\ffmpeg.exe Linux下直接调用ffmpeg命令(当然你事先已经有这个程序了)<br>
     * (必填)2.input_path:原视频路径<br>
     * (必填)3.video_converted_path:转换后视频输出路径<br>
     * (可选)4.screen_size:视频尺寸 长度乘宽度 乘号用英文小写"x"如 512x480<br>
     * (可选)5.logo:水印地址(其实在ffmpeg中有一个专门的watermark参数,logo跟它有何不同,我还没看,不过对我来说效果一样 貌似需要png图片才行)<br>
     * (可选,如果填写必须有logo才行,默认为0)6.xaxis:水印logo的横坐标(只有logo参数为一个正确路径才行) 比如0<br>
     * (可选,如果填写必须有logo才行,默认为0)6.yaxis:水印logo的纵坐标(只有logo参数为一个正确路径才行) 比如0<br>
     * (可选)vb:视频比特率,传入一个数值,单位在程序里面拼接了k
     * (可选)ab:音频比特率,传入一个数值,单位在程序里面拼接了k
     */
    public String videoTransfer(HashMap<String, String> dto) {
        // String ffmpeg_path,String input_path,String video_converted_path,String logo,String screen_size,String xaxis,String yaxis,String vb,String ab
        List<String> cmd = new ArrayList<String>();
        cmd.add(dto.get("ffmpeg_path"));
        cmd.add("-y");
        cmd.add("-i");
        cmd.add(dto.get("input_path"));
        if (null != dto.get("screen_size")) {
            cmd.add("-s");
            cmd.add(dto.get("screen_size"));
        }
        int markHeight= 50;
        int markWidth = 50;
        if (!org.springframework.util.StringUtils.isEmpty(dto.get("width"))) {
            markHeight = (int) (Integer.parseInt(dto.get("width")) * 0.1);
            markWidth = markHeight;
        }
        if (null != dto.get("logo")) {
            String logo = dto.get("logo");
            //-vf：视频旋转
            cmd.add("-vf");
            String xaxis = dto.get("xaxis");
            String yaxis = dto.get("yaxis");
            xaxis = xaxis != null && !"".equals(xaxis) ? xaxis : "0";
            yaxis = yaxis != null && !"".equals(yaxis) ? yaxis : "0";
            String logoString = "movie=" + logo + "[logo],[in][logo]overlay=x=" + xaxis + ":y=" + yaxis + "[out]";
            cmd.add(logoString);
        }
        cmd.add("-strict");
        cmd.add("-2");
        if (null != dto.get("vb") && !dto.get("vb").equals("")) {
            cmd.add("-vb");
            cmd.add(dto.get("vb") + "k");
        }
        if (null != dto.get("ab") && !dto.get("ab").equals("")) {
            cmd.add("-ab");
            cmd.add(dto.get("ab") + "k");
        }
        cmd.add("-q:v");
        cmd.add("4");
        // h264转码，可以在video标签内播放
        cmd.add("-vcodec");
        cmd.add("libx264");
        cmd.add(dto.get("video_converted_path"));
        String converted_time = CmdExecuter.exec(cmd);
        //获取转换时间
        return returnSecond(converted_time);
    }

    public static Map<String, Object> setVideoWaterMark(String fileUrl, String filePath) {
        HashMap<String, String> dto = new HashMap<String, String>();
        String uuid = UUID.randomUUID().toString().replaceAll("-", "");
        filePath = filePath + uuid + ".mp4";
        //ffmpeg程序路径
        dto.put("ffmpeg_path", ffmepgPath);
        logger.info("ffmepg程序路径：" + ffmepgPath);
        //视频输入路径
        dto.put("input_path", fileUrl);
        logger.info("输入文件路径:" + fileUrl);
        //视频输出路径
        dto.put("video_converted_path", filePath);
        // 白名单
        dto.put("whitelist", "file,http,https,rtp,udp,tcp,tls");
        //可选(注意windows下面的logo地址前面要写4个反斜杠,如果用浏览器里面调用servlet并传参只用两个,如 d:\\:/ffmpeg/input/logo.png)
        dto.put("logo", logoPath);
        logger.info("视频水印图片路径:" + logoPath);
        Map<String, String> videoSize = new FFMPEG().getVideoSize(dto);
        //长度
        dto.put("height", videoSize.get("height"));
        //宽度
        dto.put("width", videoSize.get("width"));
        //logo X坐标
        dto.put("xaxis", "30");
        //logo Y坐标
        dto.put("yaxis", "30");
        String secondsString = new FFMPEG().videoTransfer(dto);
        logger.info("转换共用:" + secondsString + "秒");
        if (StringUtils.isBlank(secondsString)) {
            throw new RuntimeException("视频添加水印异常！");
        }
        return OSSUtils.fileUpload(new File(filePath));
    }

    /**
     * 获取视频长宽
     * @param dto
     * @return
     */
    public Map<String,String> getVideoSize(HashMap<String, String> dto) {
        Map<String, String> map = new HashMap<>(2);
        List<String> cmd = new ArrayList<String>();
        cmd.add(dto.get("ffmpeg_path"));
        cmd.add("-protocol_whitelist");
        cmd.add(dto.get("whitelist"));
        cmd.add("-i");
        cmd.add(dto.get("input_path"));
        String height = "";
        String width = "";
        try {
            ProcessBuilder builder = new ProcessBuilder();
            String join = StringUtils.join(cmd, " ");
            logger.info("join:"+join);
            builder.command(cmd);
            final Process p = builder.start();
            //从输入流中读取视频信息
            BufferedReader br = new BufferedReader(new InputStreamReader(p.getErrorStream()));
            StringBuffer sb = new StringBuffer();
            String line = "";
            while ((line = br.readLine()) != null) {
                sb.append(line);
            }
            br.close();
            int resultCode = p.waitFor();
            logger.info("resultCode:"+resultCode);
            System.out.println(sb.toString());
            int start = sb.indexOf("Video:");
            String substring = sb.substring(start);
            String[] split = substring.split("\\),");
            String sb1 = "";
            String sizeStr = "";
            if (split.length > 3) {
                sb1 = split[2];
            }
            String[] split1 = sb1.split(",");
            if (split1.length > 0) {
                sizeStr = split1[0];
            }
            String[] xes = sizeStr.split("x");
            if (xes.length > 1) {
                height = xes[0].trim().split(" ")[0];
                width = xes[1].trim().split(" ")[0];
            }
        } catch (Exception e) {
            StringWriter stringWriter = new StringWriter();
            e.printStackTrace(new PrintWriter(stringWriter));
            logger.error("出错了：[\u001B[31m {} \u001B[0m]", stringWriter);
            logger.error("获取视频文件分辨率异常！");
        }
        map.put("height", height);
        map.put("width", width);
        return map;
    }
}
