package com.caimei365.manager.utils;

import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.client.RestTemplate;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.net.URL;
import java.net.URLConnection;


@Slf4j
@Component
public class GenerateUtils {


    private static String wwwServer;

    @Value("${caimei.wwwDomain}")
    public void setWwwServer(String wwwServer) {
        GenerateUtils.wwwServer = wwwServer;
    }
    /**
     * 生成www静态首页
     */
    public static void generateHome(){
        try {
            RestTemplate restTemplate = new RestTemplate();
            MultiValueMap<String, Integer> paramMap = new LinkedMultiValueMap<>();
            String uri = wwwServer + "/generate/home";
            // 发起Post请求
            String result = restTemplate.postForObject(uri, paramMap, String.class);
            log.info("生成www静态首页：" + result);
        }  catch (Exception e) {
            log.info("生成www静态首页失败！");
            log.error(e.toString(), e);
        }
    }

    /**
     * 生成www静态产品仪器页面
     * @param pageId 页面Id
     */
    public void generateProductType(Integer pageId){
        try {
            RestTemplate restTemplate = new RestTemplate();
            MultiValueMap<String, Integer> paramMap = new LinkedMultiValueMap<>();
            String uri = wwwServer + "/generate/product/type?pageId="+pageId;
            // 发起Post请求
            String result = restTemplate.postForObject(uri, paramMap, String.class);
            log.info("生成www静态产品仪器页面：" + result);
        }  catch (Exception e) {
            log.info("生成www静态产品仪器页面失败！");
            log.error(e.toString(), e);
        }
    }

    /**
     * 生成www静态采美百科产品仪器页面
     */
    public void generateBaikePage(Integer commodityType){
        try {
            RestTemplate restTemplate = new RestTemplate();
            MultiValueMap<String, Integer> paramMap = new LinkedMultiValueMap<>();
            String uri = wwwServer + "/generate/baike/page?commodityType="+commodityType;
            // 发起Post请求
            String result = restTemplate.postForObject(uri, paramMap, String.class);
            log.info("生成采美百科静态产品仪器页面：" + result);
        }  catch (Exception e) {
            log.info("生成采美百科静态产品仪器页面失败！");
            log.error(e.toString(), e);
        }
    }

    /**
     * 百度链接实时推送
     */
    public void pushBaiduLink(String param) {
        String result = "";
        PrintWriter out = null;
        BufferedReader in = null;
        try {
            //建立URL之间的连接
            URLConnection conn = new URL("http://data.zz.baidu.com/urls?site=https://www.caimei365.com&token=hgKJrx3lqsPPCf73").openConnection();
            // 设置通用的请求属性
            conn.setRequestProperty("User-Agent", "curl/7.12.1");
            conn.setRequestProperty("Host", "data.zz.baidu.com");
            conn.setRequestProperty("Content-Type", "text/plain");
            conn.setRequestProperty("Content-Length", "83");
            //发送POST请求必须设置如下两行
            conn.setDoInput(true);
            conn.setDoOutput(true);
            //获取conn对应的输出流
            out = new PrintWriter(conn.getOutputStream());
            //发送请求参数
            out.print(param.trim());
            //进行输出流的缓冲
            out.flush();
            //通过BufferedReader输入流来读取Url的响应
            in = new BufferedReader(new InputStreamReader(conn.getInputStream()));
            String line;
            while((line=in.readLine()) != null){
                result += line;
            }
        } catch (Exception e) {
            log.info("百度链接实时推送出现异常！" + e);
        } finally {
            try{
                if(out != null) {
                    out.close();
                }
                if(in != null) {
                    in.close();
                }
            } catch(IOException ex) {
                ex.printStackTrace();
                log.info("百度链接实时推送关闭连接异常！" + ex);
            }
        }
        log.info("百度链接实时推送："+result);
    }

}
